History
=======

0.2.1 (September 19th, 2019)
----------------------------
* Fix bug with typo.

0.2.0 (September 18th, 2019)
----------------------------
* Include keeper-contracts v0.12.0 and methods calls.

0.1.3 (September 10th, 2019)
----------------------------
* Support address recovery from signatures produced via web3.personal.sign.

0.1.1 (August 29th, 2019)
-----------------
* Upgrade keeper-contracts to v0.11.1
  
0.1.0 (August 19th, 2019)
-----------------
* First version after split of squid-py